[Intel-gfx] [PATCH i-g-t 2/2] lib: use test failure status for igt_set_timeout

Thomas Wood thomas.wood at intel.com
Thu Apr 9 04:14:29 PDT 2015


Use a failure status code for timeout to avoid confusion between tests
that take too long to execute versus a failure due to an operation
taking longer than expected.

Signed-off-by: Thomas Wood <thomas.wood at intel.com>
---
 lib/igt_core.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/igt_core.c b/lib/igt_core.c
index f9e92c9..e5bda86 100644
--- a/lib/igt_core.c
+++ b/lib/igt_core.c
@@ -1705,15 +1705,15 @@ out:
 
 static void igt_alarm_handler(int signal)
 {
-	/* exit with timeout status */
-	igt_fail(IGT_EXIT_TIMEOUT);
+	/* exit with failure status */
+	igt_fail(IGT_EXIT_FAILURE);
 }
 
 /**
  * igt_set_timeout:
  * @seconds: number of seconds before timeout
  *
  * Fail a test and exit with #IGT_EXIT_TIMEOUT status after the specified
  * number of seconds have elapsed. If the current test has subtests and the
  * timeout occurs outside a subtest, subsequent subtests will be skipped and
  * marked as failed.
@@ -1705,15 +1705,15 @@ out:
  * @seconds: number of seconds before timeout
  *
- * Fail a test and exit with #IGT_EXIT_TIMEOUT status after the specified
+ * Fail a test and exit with #IGT_EXIT_FAILURE status after the specified
  * number of seconds have elapsed. If the current test has subtests and the
  * timeout occurs outside a subtest, subsequent subtests will be skipped and
-- 
2.1.0



More information about the Intel-gfx mailing list